@@ -344,7 +344,9 @@ $result_trees{'chinese_mixed_with_en'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -425,7 +427,7 @@ $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'contents'}[15]{'parent'}
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'contents'}[16]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[1];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'contents'}[17]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[1];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[1]{'parent'} = $result_trees{'chinese_mixed_with_en'};
 $result_trees{'chinese_mixed_with_en'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'chinese_mixed_with_en'}{'contents'}[2];
 $result_trees{'chinese_mixed_with_en'}{'contents'}[2]{'parent'} = $result_trees{'chinese_mixed_with_en'};
@@ -518,4 +520,7 @@ $result_menus{'chinese_mixed_with_en'} = {
 $result_errors{'chinese_mixed_with_en'} = [];
 
 
+$result_floats{'chinese_mixed_with_en'} = {};
+
+
 1;
